# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKFastMarchingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkFastMarchingImageToNodePairContainerAdaptorPython
else:
    import _itkFastMarchingImageToNodePairContainerAdaptorPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.ITKFastMarchingBasePython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkImageRegionPython
import itk.itkLevelSetNodePython
import itk.itkNodePairPython
import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkFastMarchingStoppingCriterionBasePython

def itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_New():
    return itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2.New()

class itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_Pointer"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_Pointer"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_Clone(self)

    def SetAliveImage(self, iImage):
        r"""
        SetAliveImage(self, iImage)

        Parameters
        ----------
        iImage: itkImageF2 const *

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_SetAliveImage(self, iImage)

    def GetAliveImage(self):
        r"""GetAliveImage(self) -> itkImageF2"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_GetAliveImage(self)

    def SetTrialImage(self, iImage):
        r"""
        SetTrialImage(self, iImage)

        Parameters
        ----------
        iImage: itkImageF2 const *

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_SetTrialImage(self, iImage)

    def GetTrialImage(self):
        r"""GetTrialImage(self) -> itkImageF2"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_GetTrialImage(self)

    def SetForbiddenImage(self, iImage):
        r"""
        SetForbiddenImage(self, iImage)

        Parameters
        ----------
        iImage: itkImageF2 const *

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_SetForbiddenImage(self, iImage)

    def GetForbiddenImage(self):
        r"""GetForbiddenImage(self) -> itkImageF2"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_GetForbiddenImage(self)

    def SetIsForbiddenImageBinaryMask(self, _arg):
        r"""
        SetIsForbiddenImageBinaryMask(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_SetIsForbiddenImageBinaryMask(self, _arg)

    def GetIsForbiddenImageBinaryMask(self):
        r"""GetIsForbiddenImageBinaryMask(self) -> bool"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_GetIsForbiddenImageBinaryMask(self)

    def IsForbiddenImageBinaryMaskOn(self):
        r"""IsForbiddenImageBinaryMaskOn(self)"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_IsForbiddenImageBinaryMaskOn(self)

    def IsForbiddenImageBinaryMaskOff(self):
        r"""IsForbiddenImageBinaryMaskOff(self)"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_IsForbiddenImageBinaryMaskOff(self)

    def GetAlivePoints(self):
        r"""GetAlivePoints(self) -> itkVectorContainerULNPI2F"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_GetAlivePoints(self)

    def GetTrialPoints(self):
        r"""GetTrialPoints(self) -> itkVectorContainerULNPI2F"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_GetTrialPoints(self)

    def GetForbiddenPoints(self):
        r"""GetForbiddenPoints(self) -> itkVectorContainerULNPI2F"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_GetForbiddenPoints(self)

    def SetAliveValue(self, _arg):
        r"""
        SetAliveValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_SetAliveValue(self, _arg)

    def GetAliveValue(self):
        r"""GetAliveValue(self) -> float"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_GetAliveValue(self)

    def SetTrialValue(self, _arg):
        r"""
        SetTrialValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_SetTrialValue(self, _arg)

    def GetTrialValue(self):
        r"""GetTrialValue(self) -> float"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_GetTrialValue(self)

    def Update(self):
        r"""Update(self)"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_Update(self)
    __swig_destroy__ = _itkFastMarchingImageToNodePairContainerAdaptorPython.delete_itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2

        Create a new object of the class itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2 in _itkFastMarchingImageToNodePairContainerAdaptorPython:
_itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2_swigregister(itkFastMarchingImageToNodePairContainerAdaptorIF2IF2IF2)

def itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_New():
    return itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3.New()

class itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_Pointer"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_Pointer"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_Clone(self)

    def SetAliveImage(self, iImage):
        r"""
        SetAliveImage(self, iImage)

        Parameters
        ----------
        iImage: itkImageF3 const *

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_SetAliveImage(self, iImage)

    def GetAliveImage(self):
        r"""GetAliveImage(self) -> itkImageF3"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_GetAliveImage(self)

    def SetTrialImage(self, iImage):
        r"""
        SetTrialImage(self, iImage)

        Parameters
        ----------
        iImage: itkImageF3 const *

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_SetTrialImage(self, iImage)

    def GetTrialImage(self):
        r"""GetTrialImage(self) -> itkImageF3"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_GetTrialImage(self)

    def SetForbiddenImage(self, iImage):
        r"""
        SetForbiddenImage(self, iImage)

        Parameters
        ----------
        iImage: itkImageF3 const *

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_SetForbiddenImage(self, iImage)

    def GetForbiddenImage(self):
        r"""GetForbiddenImage(self) -> itkImageF3"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_GetForbiddenImage(self)

    def SetIsForbiddenImageBinaryMask(self, _arg):
        r"""
        SetIsForbiddenImageBinaryMask(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_SetIsForbiddenImageBinaryMask(self, _arg)

    def GetIsForbiddenImageBinaryMask(self):
        r"""GetIsForbiddenImageBinaryMask(self) -> bool"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_GetIsForbiddenImageBinaryMask(self)

    def IsForbiddenImageBinaryMaskOn(self):
        r"""IsForbiddenImageBinaryMaskOn(self)"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_IsForbiddenImageBinaryMaskOn(self)

    def IsForbiddenImageBinaryMaskOff(self):
        r"""IsForbiddenImageBinaryMaskOff(self)"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_IsForbiddenImageBinaryMaskOff(self)

    def GetAlivePoints(self):
        r"""GetAlivePoints(self) -> itkVectorContainerULNPI3F"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_GetAlivePoints(self)

    def GetTrialPoints(self):
        r"""GetTrialPoints(self) -> itkVectorContainerULNPI3F"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_GetTrialPoints(self)

    def GetForbiddenPoints(self):
        r"""GetForbiddenPoints(self) -> itkVectorContainerULNPI3F"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_GetForbiddenPoints(self)

    def SetAliveValue(self, _arg):
        r"""
        SetAliveValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_SetAliveValue(self, _arg)

    def GetAliveValue(self):
        r"""GetAliveValue(self) -> float"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_GetAliveValue(self)

    def SetTrialValue(self, _arg):
        r"""
        SetTrialValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_SetTrialValue(self, _arg)

    def GetTrialValue(self):
        r"""GetTrialValue(self) -> float"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_GetTrialValue(self)

    def Update(self):
        r"""Update(self)"""
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_Update(self)
    __swig_destroy__ = _itkFastMarchingImageToNodePairContainerAdaptorPython.delete_itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3

        Create a new object of the class itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3 in _itkFastMarchingImageToNodePairContainerAdaptorPython:
_itkFastMarchingImageToNodePairContainerAdaptorPython.itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3_swigregister(itkFastMarchingImageToNodePairContainerAdaptorIF3IF3IF3)

